@@ -1,9 +1,9 @@
 import dataclasses
 import gc
 import pickle
-from typing import Optional, Type
+import sys
+from typing import Optional
 
-import cloudpickle
 import pytest
 
 import pydantic
@@ -11,6 +11,23 @@ from pydantic import BaseModel, PositiveFloat, ValidationError
 from pydantic._internal._model_construction import _PydanticWeakRef
 from pydantic.config import ConfigDict
 
+try:
+    import cloudpickle
+except ImportError:
+    cloudpickle = None
+
+pytestmark = pytest.mark.skipif(cloudpickle is None, reason='cloudpickle is not installed')
+
+cloudpickle_pypy_xfail = pytest.mark.xfail(
+    condition=sys.implementation.name == 'pypy' and sys.version_info >= (3, 11),
+    reason='Cloudpickle issue: - possibly https://github.com/cloudpipe/cloudpickle/issues/557',
+)
+
+cloudpickle_model_xfail = pytest.mark.xfail(
+    condition=sys.version_info >= (3, 14),
+    reason='Cloudpickle issue: https://github.com/cloudpipe/cloudpickle/issues/572',
+)
+
 
 class IntWrapper:
     def __init__(self, v: int):
@@ -66,7 +83,7 @@ class ImportableModel(BaseModel):
     val: PositiveFloat = 0.7
 
 
-def model_factory() -> Type:
+def model_factory() -> type:
     class NonImportableModel(BaseModel):
         foo: str
         bar: Optional[str] = None
@@ -82,10 +99,10 @@ def model_factory() -> Type:
         (ImportableModel, False),
         (ImportableModel, True),
         # Locally-defined model can only be pickled with cloudpickle.
-        (model_factory(), True),
+        pytest.param(model_factory(), True, marks=(cloudpickle_pypy_xfail, cloudpickle_model_xfail)),
     ],
 )
-def test_pickle_model(model_type: Type, use_cloudpickle: bool):
+def test_pickle_model(model_type: type, use_cloudpickle: bool):
     if use_cloudpickle:
         model_type = cloudpickle.loads(cloudpickle.dumps(model_type))
     else:
@@ -113,7 +130,7 @@ class ImportableNestedModel(BaseModel):
     inner: ImportableModel
 
 
-def nested_model_factory() -> Type:
+def nested_model_factory() -> type:
     class NonImportableNestedModel(BaseModel):
         inner: ImportableModel
 
@@ -127,10 +144,10 @@ def nested_model_factory() -> Type:
         (ImportableNestedModel, False),
         (ImportableNestedModel, True),
         # Locally-defined model can only be pickled with cloudpickle.
-        (nested_model_factory(), True),
+        pytest.param(nested_model_factory(), True, marks=(cloudpickle_pypy_xfail, cloudpickle_model_xfail)),
     ],
 )
-def test_pickle_nested_model(model_type: Type, use_cloudpickle: bool):
+def test_pickle_nested_model(model_type: type, use_cloudpickle: bool):
     if use_cloudpickle:
         model_type = cloudpickle.loads(cloudpickle.dumps(model_type))
     else:
@@ -157,7 +174,7 @@ class ImportableDataclass:
     b: float
 
 
-def dataclass_factory() -> Type:
+def dataclass_factory() -> type:
     @pydantic.dataclasses.dataclass
     class NonImportableDataclass:
         a: int
@@ -172,7 +189,7 @@ class ImportableBuiltinDataclass:
     b: float
 
 
-def builtin_dataclass_factory() -> Type:
+def builtin_dataclass_factory() -> type:
     @dataclasses.dataclass
     class NonImportableBuiltinDataclass:
         a: int
@@ -185,7 +202,7 @@ class ImportableChildDataclass(ImportableDataclass):
     pass
 
 
-def child_dataclass_factory() -> Type:
+def child_dataclass_factory() -> type:
     class NonImportableChildDataclass(ImportableDataclass):
         pass
 
@@ -201,15 +218,15 @@ def child_dataclass_factory() -> Type:
         (ImportableChildDataclass, False),
         (ImportableChildDataclass, True),
         # Locally-defined Pydantic dataclass can only be pickled with cloudpickle.
-        (dataclass_factory(), True),
+        pytest.param(dataclass_factory(), True, marks=cloudpickle_pypy_xfail),
         (child_dataclass_factory(), True),
         # Pydantic dataclass generated from builtin can only be pickled with cloudpickle.
-        (pydantic.dataclasses.dataclass(ImportableBuiltinDataclass), True),
+        pytest.param(pydantic.dataclasses.dataclass(ImportableBuiltinDataclass), True, marks=cloudpickle_pypy_xfail),
         # Pydantic dataclass generated from locally-defined builtin can only be pickled with cloudpickle.
-        (pydantic.dataclasses.dataclass(builtin_dataclass_factory()), True),
+        pytest.param(pydantic.dataclasses.dataclass(builtin_dataclass_factory()), True, marks=cloudpickle_pypy_xfail),
     ],
 )
-def test_pickle_dataclass(dataclass_type: Type, use_cloudpickle: bool):
+def test_pickle_dataclass(dataclass_type: type, use_cloudpickle: bool):
     if use_cloudpickle:
         dataclass_type = cloudpickle.loads(cloudpickle.dumps(dataclass_type))
     else:
@@ -244,7 +261,7 @@ class ImportableNestedDataclassModel(BaseModel):
     inner: ImportableBuiltinDataclass
 
 
-def nested_dataclass_model_factory() -> Type:
+def nested_dataclass_model_factory() -> type:
     class NonImportableNestedDataclassModel(BaseModel):
         inner: ImportableBuiltinDataclass
 
@@ -258,10 +275,10 @@ def nested_dataclass_model_factory() -> Type:
         (ImportableNestedDataclassModel, False),
         (ImportableNestedDataclassModel, True),
         # Locally-defined model can only be pickled with cloudpickle.
-        (nested_dataclass_model_factory(), True),
+        pytest.param(nested_dataclass_model_factory(), True, marks=(cloudpickle_pypy_xfail, cloudpickle_model_xfail)),
     ],
 )
-def test_pickle_dataclass_nested_in_model(model_type: Type, use_cloudpickle: bool):
+def test_pickle_dataclass_nested_in_model(model_type: type, use_cloudpickle: bool):
     if use_cloudpickle:
         model_type = cloudpickle.loads(cloudpickle.dumps(model_type))
     else:
@@ -284,7 +301,7 @@ class ImportableModelWithConfig(BaseModel):
     model_config = ConfigDict(title='MyTitle')
 
 
-def model_with_config_factory() -> Type:
+def model_with_config_factory() -> type:
     class NonImportableModelWithConfig(BaseModel):
         model_config = ConfigDict(title='MyTitle')
 
@@ -296,10 +313,10 @@ def model_with_config_factory() -> Type:
     [
         (ImportableModelWithConfig, False),
         (ImportableModelWithConfig, True),
-        (model_with_config_factory(), True),
+        pytest.param(model_with_config_factory(), True, marks=cloudpickle_pypy_xfail),
     ],
 )
-def test_pickle_model_with_config(model_type: Type, use_cloudpickle: bool):
+def test_pickle_model_with_config(model_type: type, use_cloudpickle: bool):
     if use_cloudpickle:
         model_type = cloudpickle.loads(cloudpickle.dumps(model_type))
     else:
